pub struct Integer64(i64);Expand description
An integer wrapping a i64, performing arithmetic overflow checks if the
checked_i64 feature is enabled.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Div<&Integer64> for &FixedDecimal9
impl Div<&Integer64> for &FixedDecimal9
Sourcetype Output = FixedDecimal9
type Output = FixedDecimal9
The resulting type after applying the
/ operator.Sourceimpl Div<Integer64> for FixedDecimal9
impl Div<Integer64> for FixedDecimal9
Sourceimpl DivAssign<&Integer64> for FixedDecimal9
impl DivAssign<&Integer64> for FixedDecimal9
Sourcefn div_assign(&mut self, rhs: &Integer64)
fn div_assign(&mut self, rhs: &Integer64)
Performs the
/= operation. Read moreSourceimpl Integer for Integer64
impl Integer for Integer64
Sourcefn from_usize(i: usize) -> Self
fn from_usize(i: usize) -> Self
Obtains an integer from a primitive
usize integer.Sourceimpl Mul<&Integer64> for &FixedDecimal9
impl Mul<&Integer64> for &FixedDecimal9
Sourcetype Output = FixedDecimal9
type Output = FixedDecimal9
The resulting type after applying the
* operator.Sourceimpl Mul<Integer64> for FixedDecimal9
impl Mul<Integer64> for FixedDecimal9
Sourceimpl PartialOrd for Integer64
impl PartialOrd for Integer64
Sourceimpl Rational<Integer64> for FixedDecimal9
impl Rational<Integer64> for FixedDecimal9
Sourcefn ratio_i(num: Integer64, denom: Integer64) -> Self
fn ratio_i(num: Integer64, denom: Integer64) -> Self
Obtains a number equal to the ratio between the given numerator and
denominator.
Sourcefn to_f64(&self) -> f64
fn to_f64(&self) -> f64
Converts a number into its floating-point approximation. This can be
useful to print approximation of large numbers.
Sourcefn is_exact() -> bool
fn is_exact() -> bool
Whether this type represents exact arithmetic, i.e.
Self::epsilon()
is zero.Sourcefn description() -> &'static str
fn description() -> &'static str
Description of the implemented arithmetic, e.g. “64-bit floating point
arithmetic”.
Sourcefn mul_up(&self, rhs: &Self) -> Self
fn mul_up(&self, rhs: &Self) -> Self
Multiplication, rounding up for types that perform a rounding on this
operation.
Sourcefn div_up_as_keep_factor(&self, rhs: &Self) -> Self
fn div_up_as_keep_factor(&self, rhs: &Self) -> Self
Performs a division to obtain a keep factor. The division is rounded up
for types that cannot compute the result precisely. Additionally,
types may further round the result, which can be useful with exact
arithmetic, to avoid complexity explosion of rational numbers.
Sourcefn from_usize(i: usize) -> Self
fn from_usize(i: usize) -> Self
Obtains a number equal to the given integer.
impl Copy for Integer64
impl Eq for Integer64
impl IntegerRef<Integer64> for &Integer64
impl RationalRef<&Integer64, FixedDecimal9> for &FixedDecimal9
impl StructuralPartialEq for Integer64