pub enum WriteTieOrder {
Always,
Never,
OnlyNonTrivial,
}Expand description
Policy to write the tie order.
Variants
Always
Always write the tie order, even if it is trivial.
Never
Never write the tie order, but panics if it is non-trivial.
OnlyNonTrivial
Only write the tie order if it is non-trivial.