pub struct WorkStealingRangeFactory {
num_elements: usize,
ranges: Arc<Vec<AtomicRange>>,
}Expand description
A factory for ranges that implement work stealing among threads.
Whenever a thread finishes processing its range, it looks for another range to steal from. It then divides that range into two and steals a half, to continue processing items.
Fields
num_elements: usizeTotal number of elements to iterate over.
ranges: Arc<Vec<AtomicRange>>Handle to the ranges of all the threads.