enum MainStatus {
Waiting,
Ready,
WorkerPanic,
}Expand description
Status of the main thread.
Variants
Waiting
The main thread is waiting for the worker threads to finish a round.
Ready
The main thread is ready to prepare the next round.
WorkerPanic
One of the worker threads panicked.