struct PanicNotifier<'a> {
id: usize,
main_status: &'a Status<MainStatus>,
}Expand description
Object whose destructor notifies the main thread that a panic happened.
The way to use this is to create an instance before a section that may
panic, and to std::mem::forget() it at the end of the section. That way:
- If a panic happens, the
std::mem::forget()call will be skipped but the destructor will run due to RAII. - If no panic happens, the destructor won’t run because this object will be forgotten.
Fields
id: usizeThread index.
main_status: &'a Status<MainStatus>Status of the main thread.