struct Status<T> {
mutex: Mutex<T>,
condvar: Condvar,
}Fields
mutex: Mutex<T>condvar: CondvarImplementations
Sourceimpl<T> Status<T>
impl<T> Status<T>
Sourcefn try_notify_one(&self, t: T) -> Result<(), PoisonError<MutexGuard<'_, T>>>
fn try_notify_one(&self, t: T) -> Result<(), PoisonError<MutexGuard<'_, T>>>
Attempts to set the status to the given value and notifies one waiting thread.
Fails if the Mutex is poisoned.
Sourcefn notify_one_if(&self, predicate: impl Fn(&T) -> bool, t: T)
fn notify_one_if(&self, predicate: impl Fn(&T) -> bool, t: T)
If the predicate is true on this status, sets the status to the given value and notifies one waiting thread.
Sourcefn notify_all(&self, t: T)
fn notify_all(&self, t: T)
Sets the status to the given value and notifies all waiting threads.
Sourcefn wait_while(&self, predicate: impl FnMut(&mut T) -> bool) -> MutexGuard<'_, T>
fn wait_while(&self, predicate: impl FnMut(&mut T) -> bool) -> MutexGuard<'_, T>
Waits until the predicate is true on this status.
This returns a MutexGuard, allowing to further inspect or modify the
status.