ThreadContext

Struct ThreadContext 

struct ThreadContext<'env, Rn: Range, Input, Output, Accum: ThreadAccumulator<Input, Output>> {
    id: usize,
    num_active_threads: Arc<AtomicUsize>,
    worker_status: Arc<Status<WorkerStatus>>,
    main_status: Arc<Status<MainStatus>>,
    range: Rn,
    input: &'env [Input],
    output: Arc<Mutex<Option<Output>>>,
    accumulator: Accum,
}
Context object owned by a worker thread.

Fields

id: usize

Thread index.

num_active_threads: Arc<AtomicUsize>

Number of worker threads active in the current round.

worker_status: Arc<Status<WorkerStatus>>

Status of the worker threads.

main_status: Arc<Status<MainStatus>>

Status of the main thread.

range: Rn

Range of items that this worker thread needs to process.

input: &'env [Input]

Reference to the inputs to process.

output: Arc<Mutex<Option<Output>>>

Output that this thread writes to.

accumulator: Accum

Function to map and reduce inputs into the output.

Implementations

Source

impl<Rn: Range, Input, Output, Accum: ThreadAccumulator<Input, Output>> ThreadContext<'_, Rn, Input, Output, Accum>

fn run(&self)

Main function run by this thread.