pub struct ParsingOptions {
pub remove_withdrawn_candidates: bool,
pub remove_empty_ballots: bool,
pub optimize_layout: bool,
}Expand description
Options to control the parsing process.
Fields
remove_withdrawn_candidates: boolWhether to remove withdrawn candidates from the ballots they appear in.
remove_empty_ballots: boolWhether to remove ballots that rank no candidate. When
remove_withdrawn_candidates is true, this also removes ballots
that only rank withdrawn candidates.
optimize_layout: boolWhether to optimize the layout of ballots in memory. This may entail sorting the ballots.