pub struct ElectionBuilder {
title: Option<String>,
num_seats: Option<usize>,
num_ballots: Option<usize>,
candidates: Vec<Candidate>,
ballots: Vec<Ballot>,
tie_order: Option<HashMap<usize, usize>>,
}Expand description
Builder for the Election type.
Fields
title: Option<String>num_seats: Option<usize>num_ballots: Option<usize>candidates: Vec<Candidate>ballots: Vec<Ballot>tie_order: Option<HashMap<usize, usize>>Implementations
Sourceimpl ElectionBuilder
impl ElectionBuilder
Sourcepub fn num_ballots(self, num_ballots: usize) -> Self
pub fn num_ballots(self, num_ballots: usize) -> Self
Sets the number of ballots cast in the election.
Sourcepub fn check_num_ballots(self, num_ballots: usize) -> Self
pub fn check_num_ballots(self, num_ballots: usize) -> Self
Checks that the given number of ballots is consistent with the actual
number of ballots previously set with Self::ballots().
Sourcepub fn candidates(self, candidates: impl Into<Vec<Candidate>>) -> Self
pub fn candidates(self, candidates: impl Into<Vec<Candidate>>) -> Self
Sets the list of candidates in the election.