pub struct VoteCountingThreadPool<'scope, I, R> {
pool: ThreadPool<'scope, VoteAccumulator<I, R>>,
keep_factors: Arc<RwLock<Vec<R>>>,
}Expand description
A thread pool tied to a scope, that can perform vote counting rounds.
Fields
pool: ThreadPool<'scope, VoteAccumulator<I, R>>Inner thread pool.
keep_factors: Arc<RwLock<Vec<R>>>Storage for the keep factors, used as input of the current round by the worker threads.
Implementations
Sourceimpl<'scope, I, R> VoteCountingThreadPool<'scope, I, R>
impl<'scope, I, R> VoteCountingThreadPool<'scope, I, R>
Sourcepub fn new<'env>(
thread_scope: &'scope Scope<'scope, 'env>,
num_threads: NonZeroUsize,
range_strategy: RangeStrategy,
election: &'env Election,
pascal: Option<&'env [Vec<I>]>,
) -> Self
pub fn new<'env>( thread_scope: &'scope Scope<'scope, 'env>, num_threads: NonZeroUsize, range_strategy: RangeStrategy, election: &'env Election, pascal: Option<&'env [Vec<I>]>, ) -> Self
Creates a new pool tied to the given scope, with the given number of threads and references to the necessary election inputs.
Sourcepub fn accumulate_votes(&self, keep_factors: &[R]) -> VoteAccumulator<I, R>
pub fn accumulate_votes(&self, keep_factors: &[R]) -> VoteAccumulator<I, R>
Accumulates votes from the election ballots based on the given keep factors.