pub struct Election {
pub title: String,
pub num_candidates: usize,
pub num_seats: usize,
pub num_ballots: usize,
pub candidates: Vec<Candidate>,
pub ballots: Vec<Ballot>,
pub tie_order: HashMap<usize, usize>,
}Expand description
Election input, representing a parsed ballot file.
Fields
title: StringName of the election.
num_candidates: usizeNumber of candidates.
num_seats: usizeNumber of elected seats.
num_ballots: usizeNumber of ballots that were cast in the election.
candidates: Vec<Candidate>Candidates in this election.
ballots: Vec<Ballot>Ballots that were cast in this election.
tie_order: HashMap<usize, usize>Tie-break order of candidates, mapping each candidate ID to its order in the tie break.
Implementations
Sourceimpl Election
impl Election
Sourcepub fn builder() -> ElectionBuilder
pub fn builder() -> ElectionBuilder
Returns a new builder.
Sourcepub fn has_any_tied_ballot(&self) -> bool
pub fn has_any_tied_ballot(&self) -> bool
Returns true if any ballot contains candidates ranked equally.
pub(crate) fn debug_allocations(&self)